==> wurld-0.1.tar.gz: wurld-0.1/src/PythonObject.h <==
/*===========================================================================*\

   $Id$

   

   Copyright (C) 2003 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:

   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#ifndef PYTHONOBJECT_H
#define PYTHONOBJECT_H

#include "GameObject.h"
#include "RenderableObject.h"
#include "Moveable.h"
#include <Python.h>

class PythonObject : public GameObject, public RenderableObject {
   private:
      PyObject *engineFrameCallback;
      PyObject *renderFrameCallback;
      MoveablePtr moveable;

   public:

      PythonObject();

      ~PythonObject();
      
      virtual void processEngineFrame(GameEngine &engine);

      virtual void processRenderFrame(GameEngine &engine, Float elapsed);

      virtual void render(Scene &scene);

      /**
       * Set the engine frame callback.
       */
      void setEngineFrameCallback(PyObject *callback);

      /**
       * Sets the render frame callback.
       */
      void setRenderFrameCallback(PyObject *callback);

      /** Sets the associated moveable object */
      void setMoveable(const MoveablePtr &newMoveable) {
	 moveable = newMoveable;
      }

      /** returns the associated moveable object. */
      MoveablePtr getMoveable() {
	 return moveable;
      }
};

SPUG_RCPTR(PythonObject);

#endif

==> wurld-0.3.tar.gz: wurld-0.3/src/PythonObject.h <==
/*===========================================================================*\

   $Id$

   

   Copyright (C) 2003 Michael A. Muller

   Permission is granted to use, modify and redistribute this code,
   providing that the following conditions are met:

   1) This copyright/licensing notice must remain intact.
   2) If the code is modified and redistributed, the modifications must 
   include documentation indicating that the code has been modified.
   3) The author(s) of this code must be indemnified and held harmless
   against any damage resulting from the use of this code.

   This code comes with ABSOLUTELY NO WARRANTEE, not even the implied 
   warrantee of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

\*===========================================================================*/

#ifndef PYTHONOBJECT_H
#define PYTHONOBJECT_H

#include "GameObject.h"
#include "RenderableObject.h"
#include "Moveable.h"
#include <Python.h>

class PythonObject : public GameObject, public RenderableObject, 
                     public CollisionHandler {
   private:
      PyObject *engineFrameCallback, *renderFrameCallback, *collisionCallback;
      MoveablePtr moveable;

      static void setCallback(PyObject *&callbackVar, PyObject *callback);

   public:

      PythonObject();

      ~PythonObject();
      
      virtual void processEngineFrame(GameEngine &engine);

      virtual void processRenderFrame(GameEngine &engine, Float elapsed);

      virtual void render(Scene &scene);

      virtual void handleCollision(const Collidable &other);

      /**
       * Set the engine frame callback.
       */
      void setEngineFrameCallback(PyObject *callback);

      /**
       * Sets the render frame callback.
       */
      void setRenderFrameCallback(PyObject *callback);

      /**
       * Sets the collision callback.
       */
      void setCollisionCallback(PyObject *callback);

      /** Sets the associated moveable object */
      void setMoveable(const MoveablePtr &newMoveable);

      /** returns the associated moveable object. */
      MoveablePtr getMoveable() {
	 return moveable;
      }
};

SPUG_RCPTR(PythonObject);

#endif
